from setuptools import setup, Extension, find_packages
import platform

extra_compile_args = []
extra_link_args = []

# Set C++17 flag based on the compiler
if platform.system() == "Windows":
    extra_compile_args.append('/std:c++17')
else:
    extra_compile_args.append('-std=c++17')

tree_structurer_module = Extension(
    'prodir._tree_structurer',  # Remove 'src.' from the module name
    sources=['src/prodir/cpp/bindings.cpp', 'src/prodir/cpp/tree_structurer.cpp'],
    include_dirs=['src/prodir/tree_structurer/cpp'],
    extra_compile_args=extra_compile_args,
    extra_link_args=extra_link_args,
)

setup(
    name='prodir',
    version='0.0.9',
    description='A module for analyzing directory structures',
    ext_modules=[tree_structurer_module],
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    entry_points={
        "console_scripts": [
            "prodir=prodir.__main__:main",
        ],
    },
)